You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vo...@apache.org on 2015/09/03 12:10:30 UTC

[3/7] ignite git commit: IGNITE-1364: Renaming GG_ -> IGNITE_

IGNITE-1364: Renaming GG_ -> IGNITE_


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/7c4165ee
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/7c4165ee
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/7c4165ee

Branch: refs/heads/ignite-1364
Commit: 7c4165eebb4a7965baba808708e03e489916813f
Parents: 509dbd5
Author: vozerov-gridgain <vo...@gridgain.com>
Authored: Thu Sep 3 12:59:03 2015 +0300
Committer: vozerov-gridgain <vo...@gridgain.com>
Committed: Thu Sep 3 12:59:03 2015 +0300

----------------------------------------------------------------------
 .../main/cpp/core-test/src/cache_query_test.cpp |   8 +-
 .../src/main/cpp/core-test/src/cache_test.cpp   |  30 ++---
 .../cpp/core-test/src/grid_factory_test.cpp     |  12 +-
 .../src/portable_reader_writer_raw_test.cpp     |  98 +++++++--------
 .../src/portable_reader_writer_test.cpp         | 126 +++++++++----------
 .../cpp/core/include/gridgain/cache/cache.h     |  12 +-
 .../include/gridgain/cache/cache_peek_mode.h    |  20 +--
 .../include/gridgain/cache/query/query_cursor.h |   8 +-
 .../main/cpp/core/include/gridgain/grid_error.h |  74 +++++------
 .../gridgain/impl/interop/interop_memory.h      |  14 +--
 .../impl/portable/portable_id_resolver.h        |   2 +-
 .../impl/portable/portable_reader_impl.h        |  10 +-
 .../include/gridgain/portable/portable_type.h   |  10 +-
 .../src/main/cpp/core/src/grid_error.cpp        |  70 +++++------
 .../src/main/cpp/core/src/grid_factory.cpp      |  24 ++--
 .../main/cpp/core/src/impl/cache/cache_impl.cpp |   2 +-
 .../core/src/impl/cache/query/query_impl.cpp    |  12 +-
 .../src/impl/interop/interop_input_stream.cpp   |   4 +-
 .../core/src/impl/interop/interop_memory.cpp    |  24 ++--
 .../src/impl/portable/portable_reader_impl.cpp  |  14 +--
 .../src/impl/portable/portable_writer_impl.cpp  |  10 +-
 21 files changed, 292 insertions(+), 292 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core-test/src/cache_query_test.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core-test/src/cache_query_test.cpp b/modules/platform/src/main/cpp/core-test/src/cache_query_test.cpp
index de4a8b2..5f3d79b 100644
--- a/modules/platform/src/main/cpp/core-test/src/cache_query_test.cpp
+++ b/modules/platform/src/main/cpp/core-test/src/cache_query_test.cpp
@@ -205,7 +205,7 @@ struct CacheQueryTestSuiteFixture {
 
         Grid grid0 = GridFactory::Start(cfg, &err);
 
-        if (err.GetCode() != GridError::GG_SUCCESS)
+        if (err.GetCode() != GridError::IGNITE_SUCCESS)
             BOOST_ERROR(err.GetText());
 
         grid = grid0;
@@ -235,7 +235,7 @@ void CheckHasNextFail(QueryCursor<int, QueryPerson>& cur)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_GENERIC);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_GENERIC);
     }
 }
 
@@ -254,7 +254,7 @@ void CheckGetNextFail(QueryCursor<int, QueryPerson>& cur)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_GENERIC);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_GENERIC);
     }
 }
 
@@ -275,7 +275,7 @@ void CheckGetAllFail(QueryCursor<int, QueryPerson>& cur)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_GENERIC);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_GENERIC);
     }
 }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core-test/src/cache_test.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core-test/src/cache_test.cpp b/modules/platform/src/main/cpp/core-test/src/cache_test.cpp
index a531252..134c118 100644
--- a/modules/platform/src/main/cpp/core-test/src/cache_test.cpp
+++ b/modules/platform/src/main/cpp/core-test/src/cache_test.cpp
@@ -117,7 +117,7 @@ struct CacheTestSuiteFixture {
 
             Grid grid = GridFactory::Start(cfg, stream.str().c_str(), &err);
                 
-            if (err.GetCode() != GridError::GG_SUCCESS)
+            if (err.GetCode() != GridError::IGNITE_SUCCESS)
                 BOOST_FAIL(err.GetText());
 
             if (i == 0)
@@ -150,13 +150,13 @@ BOOST_AUTO_TEST_CASE(TestRemoveAllKeys)
     cache.Put(2, 2);
     cache.Put(3, 3);
 
-    int size = cache.Size(cache::GG_PEEK_MODE_PRIMARY);
+    int size = cache.Size(cache::IGNITE_PEEK_MODE_PRIMARY);
 
     BOOST_REQUIRE(3 == size);
 
     cache.RemoveAll();
 
-    size = cache.Size(cache::GG_PEEK_MODE_ALL);
+    size = cache.Size(cache::IGNITE_PEEK_MODE_ALL);
 
     BOOST_REQUIRE(0 == size);
 
@@ -170,7 +170,7 @@ BOOST_AUTO_TEST_CASE(TestRemoveAllKeys)
 
     cache.RemoveAll(keySet);
 
-    size = cache.Size(cache::GG_PEEK_MODE_PRIMARY);
+    size = cache.Size(cache::IGNITE_PEEK_MODE_PRIMARY);
 
     BOOST_REQUIRE(1 == size);
 }
@@ -360,11 +360,11 @@ BOOST_AUTO_TEST_CASE(TestLocalClear)
 
     cache.Put(0, 2);
 
-    BOOST_REQUIRE(2 == cache.LocalPeek(0, cache::GG_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(2 == cache.LocalPeek(0, cache::IGNITE_PEEK_MODE_PRIMARY));
 
     cache.LocalClear(0);
 
-    BOOST_REQUIRE(0 == cache.LocalPeek(0, cache::GG_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(0 == cache.LocalPeek(0, cache::IGNITE_PEEK_MODE_PRIMARY));
 }
 
 BOOST_AUTO_TEST_CASE(TestLocalClearAll)
@@ -378,13 +378,13 @@ BOOST_AUTO_TEST_CASE(TestLocalClearAll)
 
     std::set<int> keySet(keys, keys + 2);
 
-    BOOST_REQUIRE(3 == cache.LocalPeek(0, cache::GG_PEEK_MODE_PRIMARY));
-    BOOST_REQUIRE(3 == cache.LocalPeek(1, cache::GG_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(3 == cache.LocalPeek(0, cache::IGNITE_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(3 == cache.LocalPeek(1, cache::IGNITE_PEEK_MODE_PRIMARY));
 
     cache.LocalClearAll(keySet);
 
-    BOOST_REQUIRE(0 == cache.LocalPeek(0, cache::GG_PEEK_MODE_PRIMARY));
-    BOOST_REQUIRE(0 == cache.LocalPeek(1, cache::GG_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(0 == cache.LocalPeek(0, cache::IGNITE_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(0 == cache.LocalPeek(1, cache::IGNITE_PEEK_MODE_PRIMARY));
 }
 
 BOOST_AUTO_TEST_CASE(TestSizes)
@@ -398,7 +398,7 @@ BOOST_AUTO_TEST_CASE(TestSizes)
 
     BOOST_REQUIRE(2 <= cache.Size());
 
-    BOOST_REQUIRE(1 <= cache.LocalSize(cache::GG_PEEK_MODE_PRIMARY));
+    BOOST_REQUIRE(1 <= cache.LocalSize(cache::IGNITE_PEEK_MODE_PRIMARY));
 }
 
 BOOST_AUTO_TEST_CASE(TestLocalEvict)
@@ -407,7 +407,7 @@ BOOST_AUTO_TEST_CASE(TestLocalEvict)
 
     cache.Put(1, 5);
 
-    BOOST_REQUIRE(5 == cache.LocalPeek(1, cache::GG_PEEK_MODE_ONHEAP));
+    BOOST_REQUIRE(5 == cache.LocalPeek(1, cache::IGNITE_PEEK_MODE_ONHEAP));
 
     int keys[] = { 0, 1 };
 
@@ -415,11 +415,11 @@ BOOST_AUTO_TEST_CASE(TestLocalEvict)
 
     cache.LocalEvict(keySet);
 
-    BOOST_REQUIRE(0 == cache.LocalPeek(1, cache::GG_PEEK_MODE_ONHEAP));
+    BOOST_REQUIRE(0 == cache.LocalPeek(1, cache::IGNITE_PEEK_MODE_ONHEAP));
 
     BOOST_REQUIRE(5 == cache.Get(1));
 
-    BOOST_REQUIRE(5 == cache.LocalPeek(1, cache::GG_PEEK_MODE_ONHEAP));
+    BOOST_REQUIRE(5 == cache.LocalPeek(1, cache::IGNITE_PEEK_MODE_ONHEAP));
 }
 
 BOOST_AUTO_TEST_CASE(TestPortable)
@@ -450,7 +450,7 @@ BOOST_AUTO_TEST_CASE(TestCreateCache)
 
     grid0.CreateCache<int, int>("dynamic_cache", &err);
 
-    BOOST_REQUIRE(err.GetCode() != GridError::GG_SUCCESS);
+    BOOST_REQUIRE(err.GetCode() != GridError::IGNITE_SUCCESS);
 }
 
 BOOST_AUTO_TEST_CASE(TestGetOrCreateCache)

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core-test/src/grid_factory_test.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core-test/src/grid_factory_test.cpp b/modules/platform/src/main/cpp/core-test/src/grid_factory_test.cpp
index e1a098c..253a692 100644
--- a/modules/platform/src/main/cpp/core-test/src/grid_factory_test.cpp
+++ b/modules/platform/src/main/cpp/core-test/src/grid_factory_test.cpp
@@ -50,14 +50,14 @@ BOOST_AUTO_TEST_CASE(TestGridFactory)
     // Start two grids
     Grid grid1 = GridFactory::Start(cfg, "gridFactoryTest-1", &err);
     
-    if (err.GetCode() != GridError::GG_SUCCESS)
+    if (err.GetCode() != GridError::IGNITE_SUCCESS)
         BOOST_ERROR(err.GetText());
     
     BOOST_REQUIRE(strcmp(grid1.GetName(), "gridFactoryTest-1") == 0);
 
     Grid grid2 = GridFactory::Start(cfg, "gridFactoryTest-2", &err);
 
-    if (err.GetCode() != GridError::GG_SUCCESS)
+    if (err.GetCode() != GridError::IGNITE_SUCCESS)
         BOOST_ERROR(err.GetText());
 
     BOOST_REQUIRE(strcmp(grid2.GetName(), "gridFactoryTest-2") == 0);
@@ -65,7 +65,7 @@ BOOST_AUTO_TEST_CASE(TestGridFactory)
     // Test get
     Grid grid0 = GridFactory::Get("gridFactoryTest-1", &err);
     
-    if (err.GetCode() != GridError::GG_SUCCESS)
+    if (err.GetCode() != GridError::IGNITE_SUCCESS)
         BOOST_ERROR(err.GetText());
 
     BOOST_REQUIRE(strcmp(grid0.GetName(), grid1.GetName()) == 0);
@@ -74,16 +74,16 @@ BOOST_AUTO_TEST_CASE(TestGridFactory)
     GridFactory::Stop(grid1.GetName(), true);
     
     GridFactory::Get("gridFactoryTest-1", &err);
-    BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_GENERIC);
+    BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_GENERIC);
     
     GridFactory::Get("gridFactoryTest-2", &err);
-    BOOST_REQUIRE(err.GetCode() == GridError::GG_SUCCESS);
+    BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_SUCCESS);
 
     // Stop all
     GridFactory::StopAll(true);
     
     GridFactory::Get("gridFactoryTest-2", &err);
-    BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_GENERIC);    
+    BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_GENERIC);    
 }
 
 BOOST_AUTO_TEST_SUITE_END()
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_raw_test.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_raw_test.cpp b/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_raw_test.cpp
index 1d070b6..3eb773e 100644
--- a/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_raw_test.cpp
+++ b/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_raw_test.cpp
@@ -171,7 +171,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -184,7 +184,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -197,7 +197,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -208,7 +208,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try 
@@ -219,7 +219,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try 
@@ -230,7 +230,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try 
@@ -241,7 +241,7 @@ void CheckRawWritesRestricted(PortableRawWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 }
 
@@ -255,7 +255,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -268,7 +268,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -279,7 +279,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -290,7 +290,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -301,7 +301,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -312,7 +312,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -323,7 +323,7 @@ void CheckRawReadsRestricted(PortableRawReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 }
 
@@ -352,7 +352,7 @@ void CheckRawCollectionEmpty(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -363,7 +363,7 @@ void CheckRawCollectionEmpty(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -391,7 +391,7 @@ void CheckRawCollectionEmpty(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -430,7 +430,7 @@ void CheckRawCollection(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -441,7 +441,7 @@ void CheckRawCollection(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -481,7 +481,7 @@ void CheckRawCollection(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -512,7 +512,7 @@ void CheckRawMapEmpty(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -523,7 +523,7 @@ void CheckRawMapEmpty(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -554,7 +554,7 @@ void CheckRawMapEmpty(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -593,7 +593,7 @@ void CheckRawMap(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -604,7 +604,7 @@ void CheckRawMap(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -652,7 +652,7 @@ void CheckRawMap(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -859,7 +859,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -870,7 +870,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -902,7 +902,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -915,7 +915,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -928,7 +928,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -939,7 +939,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -964,7 +964,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -975,7 +975,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1017,7 +1017,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1030,7 +1030,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1043,7 +1043,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1054,7 +1054,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1127,7 +1127,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1138,7 +1138,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1240,7 +1240,7 @@ BOOST_AUTO_TEST_CASE(TestArrayNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1270,7 +1270,7 @@ BOOST_AUTO_TEST_CASE(TestArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1281,7 +1281,7 @@ BOOST_AUTO_TEST_CASE(TestArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1304,7 +1304,7 @@ BOOST_AUTO_TEST_CASE(TestArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1342,7 +1342,7 @@ BOOST_AUTO_TEST_CASE(TestArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1353,7 +1353,7 @@ BOOST_AUTO_TEST_CASE(TestArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1388,7 +1388,7 @@ BOOST_AUTO_TEST_CASE(TestArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1426,7 +1426,7 @@ BOOST_AUTO_TEST_CASE(TestCollectionNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1491,7 +1491,7 @@ BOOST_AUTO_TEST_CASE(TestMapNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_test.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_test.cpp b/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_test.cpp
index 5caf4d5..11e2931 100644
--- a/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_test.cpp
+++ b/modules/platform/src/main/cpp/core-test/src/portable_reader_writer_test.cpp
@@ -46,7 +46,7 @@ void CheckPrimitive(T val)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     Write<T>(writer, "test", val);
@@ -68,7 +68,7 @@ void CheckPrimitive(T val)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     T readVal = Read<T>(reader, "test");
@@ -108,7 +108,7 @@ void CheckPrimitiveArray(T dflt, T val1, T val2)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
     
     // 1. Write NULL and see what happens.
@@ -210,7 +210,7 @@ void CheckPrimitiveArray(T dflt, T val1, T val2)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(ReadArray<T>(reader, fieldName, arr1, 0) == 2);
@@ -236,7 +236,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -249,7 +249,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -262,7 +262,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -273,7 +273,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try 
@@ -284,7 +284,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try 
@@ -295,7 +295,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try 
@@ -306,7 +306,7 @@ void CheckWritesRestricted(PortableWriter& writer)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 }
 
@@ -320,7 +320,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -333,7 +333,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -344,7 +344,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -355,7 +355,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -366,7 +366,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -377,7 +377,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -388,7 +388,7 @@ void CheckReadsRestricted(PortableReader& reader)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 }
 
@@ -421,7 +421,7 @@ void CheckCollectionEmpty(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -432,7 +432,7 @@ void CheckCollectionEmpty(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -462,7 +462,7 @@ void CheckCollectionEmpty(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -505,7 +505,7 @@ void CheckCollection(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -516,7 +516,7 @@ void CheckCollection(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -558,7 +558,7 @@ void CheckCollection(CollectionType* colType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -593,7 +593,7 @@ void CheckMapEmpty(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -604,7 +604,7 @@ void CheckMapEmpty(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -637,7 +637,7 @@ void CheckMapEmpty(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -680,7 +680,7 @@ void CheckMap(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -691,7 +691,7 @@ void CheckMap(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -741,7 +741,7 @@ void CheckMap(MapType* mapType)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -865,7 +865,7 @@ BOOST_AUTO_TEST_CASE(TestGuidNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     writer.WriteNull("test");
@@ -886,7 +886,7 @@ BOOST_AUTO_TEST_CASE(TestGuidNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     Guid expVal;
@@ -918,7 +918,7 @@ BOOST_AUTO_TEST_CASE(TestString) {
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -929,7 +929,7 @@ BOOST_AUTO_TEST_CASE(TestString) {
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -940,7 +940,7 @@ BOOST_AUTO_TEST_CASE(TestString) {
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     writer.WriteString("field1", writeVal1);
@@ -967,7 +967,7 @@ BOOST_AUTO_TEST_CASE(TestString) {
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -978,7 +978,7 @@ BOOST_AUTO_TEST_CASE(TestString) {
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     char readVal1[9];
@@ -1045,7 +1045,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1056,7 +1056,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1092,7 +1092,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1105,7 +1105,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1118,7 +1118,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1129,7 +1129,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1156,7 +1156,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1167,7 +1167,7 @@ BOOST_AUTO_TEST_CASE(TestStringArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1213,7 +1213,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1226,7 +1226,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1239,7 +1239,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1250,7 +1250,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1325,7 +1325,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1336,7 +1336,7 @@ BOOST_AUTO_TEST_CASE(TestStringArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1456,7 +1456,7 @@ BOOST_AUTO_TEST_CASE(TestArrayNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1490,7 +1490,7 @@ BOOST_AUTO_TEST_CASE(TestArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1501,7 +1501,7 @@ BOOST_AUTO_TEST_CASE(TestArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1526,7 +1526,7 @@ BOOST_AUTO_TEST_CASE(TestArrayEmpty)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1568,7 +1568,7 @@ BOOST_AUTO_TEST_CASE(TestArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     try
@@ -1579,7 +1579,7 @@ BOOST_AUTO_TEST_CASE(TestArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     out.Synchronize();
@@ -1616,7 +1616,7 @@ BOOST_AUTO_TEST_CASE(TestArray)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1660,7 +1660,7 @@ BOOST_AUTO_TEST_CASE(TestCollectionNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1731,7 +1731,7 @@ BOOST_AUTO_TEST_CASE(TestMapNull)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt8("field2") == 1);
@@ -1783,7 +1783,7 @@ BOOST_AUTO_TEST_CASE(TestRawMode)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     rawWriter.WriteInt8(1);
@@ -1808,7 +1808,7 @@ BOOST_AUTO_TEST_CASE(TestRawMode)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(rawReader.ReadInt8() == 1);
@@ -1889,7 +1889,7 @@ BOOST_AUTO_TEST_CASE(TestFieldSeek)
     }
     catch (GridError& err)
     {
-        BOOST_REQUIRE(err.GetCode() == GridError::GG_ERR_PORTABLE);
+        BOOST_REQUIRE(err.GetCode() == GridError::IGNITE_ERR_PORTABLE);
     }
 
     BOOST_REQUIRE(reader.ReadInt32("val2") == 2);

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/cache/cache.h
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/cache/query/query_cursor.h b/modules/platform/src/main/cpp/core/include/gridgain/cache/query/query_cursor.h
index 844c6bc..6f8dd3e 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/cache/query/query_cursor.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/cache/query/query_cursor.h
@@ -89,7 +89,7 @@ namespace gridgain
                         return impl0->HasNext(&err);
                     else
                     {
-                        err = GridError(GridError::GG_ERR_GENERIC, 
+                        err = GridError(GridError::IGNITE_ERR_GENERIC, 
                             "Instance is not usable (did you check for error?).");
 
                         return false;
@@ -127,7 +127,7 @@ namespace gridgain
 
                         impl0->GetNext(outOp, &err);
 
-                        if (err.GetCode() == GridError::GG_SUCCESS) 
+                        if (err.GetCode() == GridError::IGNITE_SUCCESS) 
                         {
                             K& key = outOp.Get1();
                             V& val = outOp.Get2();
@@ -139,7 +139,7 @@ namespace gridgain
                     }
                     else
                     {
-                        err = GridError(GridError::GG_ERR_GENERIC,
+                        err = GridError(GridError::IGNITE_ERR_GENERIC,
                             "Instance is not usable (did you check for error?).");
 
                         return CacheEntry<K, V>();
@@ -176,7 +176,7 @@ namespace gridgain
                         impl0->GetAll(outOp, &err);
                     }
                     else
-                        err = GridError(GridError::GG_ERR_GENERIC,
+                        err = GridError(GridError::IGNITE_ERR_GENERIC,
                             "Instance is not usable (did you check for error?).");
                 }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/grid_error.h
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/impl/interop/interop_memory.h b/modules/platform/src/main/cpp/core/include/gridgain/impl/interop/interop_memory.h
index 2d9a86e..566a768 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/impl/interop/interop_memory.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/impl/interop/interop_memory.h
@@ -29,25 +29,25 @@ namespace gridgain
         namespace interop 
         {
             /** Memory header length. */
-            const int GG_MEM_HDR_LEN = 20;
+            const int IGNITE_MEM_HDR_LEN = 20;
 
             /** Memory header offset: capacity. */
-            const int GG_MEM_HDR_OFF_CAP = 8;
+            const int IGNITE_MEM_HDR_OFF_CAP = 8;
 
             /** Memory header offset: length. */
-            const int GG_MEM_HDR_OFF_LEN = 12;
+            const int IGNITE_MEM_HDR_OFF_LEN = 12;
 
             /** Memory header offset: flags. */
-            const int GG_MEM_HDR_OFF_FLAGS = 16;
+            const int IGNITE_MEM_HDR_OFF_FLAGS = 16;
 
             /** Flag: external. */
-            const int GG_MEM_FLAG_EXT = 0x1;
+            const int IGNITE_MEM_FLAG_EXT = 0x1;
 
             /** Flag: pooled. */
-            const int GG_MEM_FLAG_POOLED = 0x2;
+            const int IGNITE_MEM_FLAG_POOLED = 0x2;
 
             /** Flag: acquired. */
-            const int GG_MEM_FLAG_ACQUIRED = 0x4;
+            const int IGNITE_MEM_FLAG_ACQUIRED = 0x4;
                 
             /**
              * Interop memory.

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_id_resolver.h
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_id_resolver.h b/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_id_resolver.h
index 72e9bb0..4eaf481 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_id_resolver.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_id_resolver.h
@@ -90,7 +90,7 @@ namespace gridgain
                 virtual int32_t GetFieldId(const int32_t typeId, const char* name) {
                     if (!name)
                     {
-                        GG_ERROR_1(GridError::GG_ERR_PORTABLE, "Field name cannot be NULL.");
+                        GG_ERROR_1(GridError::IGNITE_ERR_PORTABLE, "Field name cannot be NULL.");
                     }
 
                     return type.GetFieldId(name);

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_reader_impl.h
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_reader_impl.h b/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_reader_impl.h
index 119f6c9..4437e10 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_reader_impl.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/impl/portable/portable_reader_impl.h
@@ -639,7 +639,7 @@ namespace gridgain
                     if (hdr == GG_HDR_NULL)
                         return GetNull<T>();
                     else if (hdr == GG_HDR_HND) {
-                        GG_ERROR_1(gridgain::GridError::GG_ERR_PORTABLE, "Circular references are not supported.");
+                        GG_ERROR_1(gridgain::GridError::IGNITE_ERR_PORTABLE, "Circular references are not supported.");
                     }
                     else if (hdr == GG_TYPE_PORTABLE)
                     {
@@ -802,7 +802,7 @@ namespace gridgain
                             {
                                 int32_t pos = stream->Position();
 
-                                GG_ERROR_FORMATTED_3(GridError::GG_ERR_PORTABLE, "Invalid type ID", 
+                                GG_ERROR_FORMATTED_3(GridError::IGNITE_ERR_PORTABLE, "Invalid type ID", 
                                     "position", pos, "expected", expHdr, "actual", typeId)
                             }
                         }
@@ -1031,7 +1031,7 @@ namespace gridgain
                     else {
                         int32_t pos = stream->Position() - 1;
 
-                        GG_ERROR_FORMATTED_3(GridError::GG_ERR_PORTABLE, "Invalid header", "position", pos, "expected", expHdr, "actual", typeId)
+                        GG_ERROR_FORMATTED_3(GridError::IGNITE_ERR_PORTABLE, "Invalid header", "position", pos, "expected", expHdr, "actual", typeId)
                     }
                 }
 
@@ -1054,7 +1054,7 @@ namespace gridgain
                     else {
                         int32_t pos = stream->Position() - 1;
 
-                        GG_ERROR_FORMATTED_3(GridError::GG_ERR_PORTABLE, "Invalid header", "position", pos, "expected", expHdr, "actual", typeId)
+                        GG_ERROR_FORMATTED_3(GridError::IGNITE_ERR_PORTABLE, "Invalid header", "position", pos, "expected", expHdr, "actual", typeId)
                     }
                 }
             };
@@ -1120,7 +1120,7 @@ namespace gridgain
                 else {
                     int32_t pos = stream->Position() - 1;
 
-                    GG_ERROR_FORMATTED_3(GridError::GG_ERR_PORTABLE, "Invalid header", "position", pos, "expected", GG_TYPE_STRING, "actual", typeId)
+                    GG_ERROR_FORMATTED_3(GridError::IGNITE_ERR_PORTABLE, "Invalid header", "position", pos, "expected", GG_TYPE_STRING, "actual", typeId)
                 }
             }
         }

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/portable/portable_type.h
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/portable/portable_type.h b/modules/platform/src/main/cpp/core/include/gridgain/portable/portable_type.h
index 7068e51..ca8f6c9 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/portable/portable_type.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/portable/portable_type.h
@@ -147,7 +147,7 @@ namespace gridgain
              */
             int32_t GetTypeId()
             {
-                GG_ERROR_1(GridError::GG_ERR_PORTABLE, "GetTypeId function is not defined for portable type.");
+                GG_ERROR_1(GridError::IGNITE_ERR_PORTABLE, "GetTypeId function is not defined for portable type.");
             }
 
             /**
@@ -157,7 +157,7 @@ namespace gridgain
              */
             std::string GetTypeName() 
             {
-                GG_ERROR_1(GridError::GG_ERR_PORTABLE, "GetTypeName function is not defined for portable type.");
+                GG_ERROR_1(GridError::IGNITE_ERR_PORTABLE, "GetTypeName function is not defined for portable type.");
             }
 
             /**
@@ -190,7 +190,7 @@ namespace gridgain
              */
             void Write(PortableWriter& writer, const T& obj)
             {
-                GG_ERROR_1(GridError::GG_ERR_PORTABLE, "Write function is not defined for portable type.");
+                GG_ERROR_1(GridError::IGNITE_ERR_PORTABLE, "Write function is not defined for portable type.");
             }
 
             /**
@@ -201,7 +201,7 @@ namespace gridgain
              */
             T Read(PortableReader& reader)
             {
-                GG_ERROR_1(GridError::GG_ERR_PORTABLE, "Read function is not defined for portable type.");
+                GG_ERROR_1(GridError::IGNITE_ERR_PORTABLE, "Read function is not defined for portable type.");
             }
 
             /**
@@ -222,7 +222,7 @@ namespace gridgain
              */
             T GetNull()
             {
-                GG_ERROR_1(GridError::GG_ERR_PORTABLE, "GetNull function is not defined for portable type.");
+                GG_ERROR_1(GridError::IGNITE_ERR_PORTABLE, "GetNull function is not defined for portable type.");
             }
         };
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/src/grid_error.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/src/grid_error.cpp b/modules/platform/src/main/cpp/core/src/grid_error.cpp
index feea271..95992ce 100644
--- a/modules/platform/src/main/cpp/core/src/grid_error.cpp
+++ b/modules/platform/src/main/cpp/core/src/grid_error.cpp
@@ -26,11 +26,11 @@ namespace gridgain
 {
     void GridError::ThrowIfNeeded(GridError& err)
     {
-        if (err.code != GG_SUCCESS)
+        if (err.code != IGNITE_SUCCESS)
             throw err;
     }
 
-    GridError::GridError() : code(GG_SUCCESS), msg(NULL)
+    GridError::GridError() : code(IGNITE_SUCCESS), msg(NULL)
     {
         // No-op.
     }
@@ -83,7 +83,7 @@ namespace gridgain
 
     const char* GridError::GetText()
     {
-        if (code == GG_SUCCESS)
+        if (code == IGNITE_SUCCESS)
             return "Operation completed successfully.";
         else if (msg)
             return msg;
@@ -111,7 +111,7 @@ namespace gridgain
                     if (jniMsg)
                         stream << ": " << jniMsg;
                     
-                    *err = GridError(GG_ERR_JVM_NO_CLASS_DEF_FOUND, stream.str().c_str());
+                    *err = GridError(IGNITE_ERR_JVM_NO_CLASS_DEF_FOUND, stream.str().c_str());
                 }
                 else if (jniCls0.compare("java.lang.NoSuchMethodError") == 0)
                 {
@@ -122,60 +122,60 @@ namespace gridgain
                     if (jniMsg)
                         stream << ": " << jniMsg;
 
-                    *err = GridError(GG_ERR_JVM_NO_SUCH_METHOD, stream.str().c_str());
+                    *err = GridError(IGNITE_ERR_JVM_NO_SUCH_METHOD, stream.str().c_str());
                 }
                 else if (jniCls0.compare("java.lang.IllegalArgumentException") == 0)
-                    *err = GridError(GG_ERR_ILLEGAL_ARGUMENT, jniMsg);
+                    *err = GridError(IGNITE_ERR_ILLEGAL_ARGUMENT, jniMsg);
                 else if (jniCls0.compare("java.lang.IllegalStateException") == 0)
-                    *err = GridError(GG_ERR_ILLEGAL_STATE, jniMsg);
+                    *err = GridError(IGNITE_ERR_ILLEGAL_STATE, jniMsg);
                 else if (jniCls0.compare("java.lang.UnsupportedOperationException") == 0)
-                    *err = GridError(GG_ERR_UNSUPPORTED_OPERATION, jniMsg);
+                    *err = GridError(IGNITE_ERR_UNSUPPORTED_OPERATION, jniMsg);
                 else if (jniCls0.compare("java.lang.InterruptedException") == 0)
-                    *err = GridError(GG_ERR_INTERRUPTED, jniMsg);
+                    *err = GridError(IGNITE_ERR_INTERRUPTED, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.cluster.ClusterGroupEmptyException") == 0)
-                    *err = GridError(GG_ERR_CLUSTER_GROUP_EMPTY, jniMsg);
+                    *err = GridError(IGNITE_ERR_CLUSTER_GROUP_EMPTY, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.cluster.ClusterTopologyException") == 0)
-                    *err = GridError(GG_ERR_CLUSTER_TOPOLOGY, jniMsg);
+                    *err = GridError(IGNITE_ERR_CLUSTER_TOPOLOGY, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.compute.ComputeExecutionRejectedException") == 0)
-                    *err = GridError(GG_ERR_COMPUTE_EXECUTION_REJECTED, jniMsg);
+                    *err = GridError(IGNITE_ERR_COMPUTE_EXECUTION_REJECTED, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.compute.ComputeJobFailoverException") == 0)
-                    *err = GridError(GG_ERR_COMPUTE_JOB_FAILOVER, jniMsg);
+                    *err = GridError(IGNITE_ERR_COMPUTE_JOB_FAILOVER, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.compute.ComputeTaskCancelledException") == 0)
-                    *err = GridError(GG_ERR_COMPUTE_TASK_CANCELLED, jniMsg);
+                    *err = GridError(IGNITE_ERR_COMPUTE_TASK_CANCELLED, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.compute.ComputeTaskTimeoutException") == 0)
-                    *err = GridError(GG_ERR_COMPUTE_TASK_TIMEOUT, jniMsg);
+                    *err = GridError(IGNITE_ERR_COMPUTE_TASK_TIMEOUT, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.compute.ComputeUserUndeclaredException") == 0)
-                    *err = GridError(GG_ERR_COMPUTE_USER_UNDECLARED_EXCEPTION, jniMsg);
+                    *err = GridError(IGNITE_ERR_COMPUTE_USER_UNDECLARED_EXCEPTION, jniMsg);
                 else if (jniCls0.compare("javax.cache.CacheException") == 0)
-                    *err = GridError(GG_ERR_CACHE, jniMsg);
+                    *err = GridError(IGNITE_ERR_CACHE, jniMsg);
                 else if (jniCls0.compare("javax.cache.integration.CacheLoaderException") == 0)
-                    *err = GridError(GG_ERR_CACHE_LOADER, jniMsg);
+                    *err = GridError(IGNITE_ERR_CACHE_LOADER, jniMsg);
                 else if (jniCls0.compare("javax.cache.integration.CacheWriterException") == 0)
-                    *err = GridError(GG_ERR_CACHE_WRITER, jniMsg);
+                    *err = GridError(IGNITE_ERR_CACHE_WRITER, jniMsg);
                 else if (jniCls0.compare("javax.cache.processor.EntryProcessorException") == 0)
-                    *err = GridError(GG_ERR_ENTRY_PROCESSOR, jniMsg);
+                    *err = GridError(IGNITE_ERR_ENTRY_PROCESSOR, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.cache.CacheAtomicUpdateTimeoutException") == 0)
-                    *err = GridError(GG_ERR_CACHE_ATOMIC_UPDATE_TIMEOUT, jniMsg);
+                    *err = GridError(IGNITE_ERR_CACHE_ATOMIC_UPDATE_TIMEOUT, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.cache.CachePartialUpdateException") == 0)
-                    *err = GridError(GG_ERR_CACHE_PARTIAL_UPDATE, jniMsg);
+                    *err = GridError(IGNITE_ERR_CACHE_PARTIAL_UPDATE, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.transactions.TransactionOptimisticException") == 0)
-                    *err = GridError(GG_ERR_TX_OPTIMISTIC, jniMsg);
+                    *err = GridError(IGNITE_ERR_TX_OPTIMISTIC, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.transactions.TransactionTimeoutException") == 0)
-                    *err = GridError(GG_ERR_TX_TIMEOUT, jniMsg);
+                    *err = GridError(IGNITE_ERR_TX_TIMEOUT, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.transactions.TransactionRollbackException") == 0)
-                    *err = GridError(GG_ERR_TX_ROLLBACK, jniMsg);
+                    *err = GridError(IGNITE_ERR_TX_ROLLBACK, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.transactions.TransactionHeuristicException") == 0)
-                    *err = GridError(GG_ERR_TX_HEURISTIC, jniMsg);
+                    *err = GridError(IGNITE_ERR_TX_HEURISTIC, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.IgniteAuthenticationException") == 0)
-                    *err = GridError(GG_ERR_AUTHENTICATION, jniMsg);
+                    *err = GridError(IGNITE_ERR_AUTHENTICATION, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.plugin.security.GridSecurityException") == 0)
-                    *err = GridError(GG_ERR_SECURITY, jniMsg);
+                    *err = GridError(IGNITE_ERR_SECURITY, jniMsg);
                 else if (jniCls0.compare("org.gridgain.grid.product.ProductLicenseException") == 0)
-                    *err = GridError(GG_ERR_PRODUCT_LICENSE, jniMsg);
+                    *err = GridError(IGNITE_ERR_PRODUCT_LICENSE, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.IgniteException") == 0)
-                    *err = GridError(GG_ERR_GENERIC, jniMsg);
+                    *err = GridError(IGNITE_ERR_GENERIC, jniMsg);
                 else if (jniCls0.compare("org.apache.ignite.IgniteCheckedException") == 0)
-                    *err = GridError(GG_ERR_GENERIC, jniMsg);
+                    *err = GridError(IGNITE_ERR_GENERIC, jniMsg);
                 else
                 {
                     std::stringstream stream;
@@ -187,13 +187,13 @@ namespace gridgain
 
                     stream << "]";
 
-                    *err = GridError(GG_ERR_UNKNOWN, stream.str().c_str());
+                    *err = GridError(IGNITE_ERR_UNKNOWN, stream.str().c_str());
                 }                    
             }
             else
             {
                 // JNI class name is not available. Something really weird.
-                *err = GridError(GG_ERR_UNKNOWN);
+                *err = GridError(IGNITE_ERR_UNKNOWN);
             }
         }
         else if (jniCode == IGNITE_JNI_ERR_JVM_INIT)
@@ -216,9 +216,9 @@ namespace gridgain
 
             stream << "]";
 
-            *err = GridError(GG_ERR_JVM_INIT, stream.str().c_str());
+            *err = GridError(IGNITE_ERR_JVM_INIT, stream.str().c_str());
         }
         else if (jniCode == IGNITE_JNI_ERR_JVM_ATTACH)
-            *err = GridError(GG_ERR_JVM_ATTACH, "Failed to attach to JVM.");
+            *err = GridError(IGNITE_ERR_JVM_ATTACH, "Failed to attach to JVM.");
     }
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/src/grid_factory.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/src/grid_factory.cpp b/modules/platform/src/main/cpp/core/src/grid_factory.cpp
index 59ec619..b2ef1e2 100644
--- a/modules/platform/src/main/cpp/core/src/grid_factory.cpp
+++ b/modules/platform/src/main/cpp/core/src/grid_factory.cpp
@@ -158,7 +158,7 @@ namespace gridgain
 
             if (!jvmLibFound)
             {
-                *err = GridError(GridError::GG_ERR_JVM_LIB_NOT_FOUND,
+                *err = GridError(GridError::IGNITE_ERR_JVM_LIB_NOT_FOUND,
                     "JVM library is not found (did you set JAVA_HOME environment variable?)");
 
                 failed = true;
@@ -167,7 +167,7 @@ namespace gridgain
             if (!failed) {
                 if (!LoadJvmLibrary(jvmLib))
                 {
-                    *err = GridError(GridError::GG_ERR_JVM_LIB_LOAD_FAILED, "Failed to load JVM library.");
+                    *err = GridError(GridError::IGNITE_ERR_JVM_LIB_LOAD_FAILED, "Failed to load JVM library.");
 
                     failed = true;
                 }
@@ -264,7 +264,7 @@ namespace gridgain
                 }
             }
             else {
-                *err = GridError(GridError::GG_ERR_JVM_NO_CLASSPATH,
+                *err = GridError(GridError::IGNITE_ERR_JVM_NO_CLASSPATH,
                     "Java classpath is empty (did you set GRIDGAIN_HOME environment variable?)");
 
                 failed = true;
@@ -326,14 +326,14 @@ namespace gridgain
 
             GridError::SetError(jniErr.code, jniErr.errCls, jniErr.errMsg, err);
 
-            if (err->GetCode() == GridError::GG_SUCCESS)
+            if (err->GetCode() == GridError::IGNITE_SUCCESS)
             {
                 // 2. Get environment pointer.
                 long long ptr = ctx.Get()->IgnitionEnvironmentPointer(name0, &jniErr);
 
                 GridError::SetError(jniErr.code, jniErr.errCls, jniErr.errMsg, err);
 
-                if (err->GetCode() == GridError::GG_SUCCESS)
+                if (err->GetCode() == GridError::IGNITE_SUCCESS)
                 {
                     if (ptr != 0)
                     {
@@ -346,7 +346,7 @@ namespace gridgain
                         // 4. Get fresh node reference.
                         jobject ref = ctx.Get()->IgnitionInstance(name0, &jniErr);
 
-                        if (err->GetCode() == GridError::GG_SUCCESS) {
+                        if (err->GetCode() == GridError::IGNITE_SUCCESS) {
                             if (ref)
                             {
                                 GridImpl* impl = new GridImpl(*env, ref);
@@ -355,14 +355,14 @@ namespace gridgain
                             }
                             else
                                 // Error: concurrent node stop.
-                                *err = GridError(GridError::GG_ERR_GENERIC,
+                                *err = GridError(GridError::IGNITE_ERR_GENERIC,
                                     "Failed to get grid instance because it was stopped concurrently.");
 
                         }
                     }
                     else
                         // Error: no node with the given name.
-                        *err = GridError(GridError::GG_ERR_GENERIC,
+                        *err = GridError(GridError::IGNITE_ERR_GENERIC,
                             "Failed to get grid instance because it is either not started yet or already stopped.");
                 }
             }
@@ -371,7 +371,7 @@ namespace gridgain
         }
         else
             // Error: no node with the given name.
-            *err = GridError(GridError::GG_ERR_GENERIC,
+            *err = GridError(GridError::IGNITE_ERR_GENERIC,
                 "Failed to get grid instance because it is either not started yet or already stopped.");
 
         factoryLock.Leave();
@@ -414,7 +414,7 @@ namespace gridgain
 
             GridError::SetError(jniErr.code, jniErr.errCls, jniErr.errMsg, err);
 
-            if (err->GetCode() == GridError::GG_SUCCESS)
+            if (err->GetCode() == GridError::IGNITE_SUCCESS)
             {
                 char* name0 = CopyChars(name);
 
@@ -424,7 +424,7 @@ namespace gridgain
 
                 GridError::SetError(jniErr.code, jniErr.errCls, jniErr.errMsg, err);
 
-                if (err->GetCode() == GridError::GG_SUCCESS)
+                if (err->GetCode() == GridError::IGNITE_SUCCESS)
                     res = res0;
             }
         }
@@ -455,7 +455,7 @@ namespace gridgain
              
             GridError::SetError(jniErr.code, jniErr.errCls, jniErr.errMsg, err);
 
-            if (err->GetCode() == GridError::GG_SUCCESS)
+            if (err->GetCode() == GridError::IGNITE_SUCCESS)
             {
                 ctx.Get()->IgnitionStopAll(cancel, &jniErr);
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/src/impl/cache/cache_impl.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/src/impl/cache/cache_impl.cpp b/modules/platform/src/main/cpp/core/src/impl/cache/cache_impl.cpp
index 541a8c8..f6354ec 100644
--- a/modules/platform/src/main/cpp/core/src/impl/cache/cache_impl.cpp
+++ b/modules/platform/src/main/cpp/core/src/impl/cache/cache_impl.cpp
@@ -138,7 +138,7 @@ namespace gridgain
 
             bool CacheImpl::IsEmpty(GridError* err)
             {
-                return Size(GG_PEEK_MODE_ALL, err) == 0;
+                return Size(IGNITE_PEEK_MODE_ALL, err) == 0;
             }
 
             bool CacheImpl::ContainsKey(InputOperation& inOp, GridError* err)

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/src/impl/cache/query/query_impl.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/src/impl/cache/query/query_impl.cpp b/modules/platform/src/main/cpp/core/src/impl/cache/query/query_impl.cpp
index 162a320..d10a6dd 100644
--- a/modules/platform/src/main/cpp/core/src/impl/cache/query/query_impl.cpp
+++ b/modules/platform/src/main/cpp/core/src/impl/cache/query/query_impl.cpp
@@ -56,7 +56,7 @@ namespace gridgain
                     // Check whether GetAll() was called earlier.
                     if (getAllCalled) 
                     {
-                        *err = GridError(GridError::GG_ERR_GENERIC, 
+                        *err = GridError(GridError::IGNITE_ERR_GENERIC, 
                             "Cannot use HasNext() method because GetAll() was called.");
 
                         return false;
@@ -74,7 +74,7 @@ namespace gridgain
                     // Check whether GetAll() was called earlier.
                     if (getAllCalled) 
                     {
-                        *err = GridError(GridError::GG_ERR_GENERIC, 
+                        *err = GridError(GridError::IGNITE_ERR_GENERIC, 
                             "Cannot use GetNext() method because GetAll() was called.");
 
                         return;
@@ -108,8 +108,8 @@ namespace gridgain
                     else
                     {
                         // Ensure we do not overwrite possible previous error.
-                        if (err->GetCode() == GridError::GG_SUCCESS)
-                            *err = GridError(GridError::GG_ERR_GENERIC, "No more elements available.");
+                        if (err->GetCode() == GridError::IGNITE_SUCCESS)
+                            *err = GridError(GridError::IGNITE_ERR_GENERIC, "No more elements available.");
                     }
                 }
 
@@ -118,7 +118,7 @@ namespace gridgain
                     // Check whether any of iterator methods were called.
                     if (iterCalled)
                     {
-                        *err = GridError(GridError::GG_ERR_GENERIC,
+                        *err = GridError(GridError::IGNITE_ERR_GENERIC,
                             "Cannot use GetAll() method because an iteration method was called.");
 
                         return;
@@ -127,7 +127,7 @@ namespace gridgain
                     // Check whether GetAll was called before.
                     if (getAllCalled)
                     {
-                        *err = GridError(GridError::GG_ERR_GENERIC,
+                        *err = GridError(GridError::IGNITE_ERR_GENERIC,
                             "Cannot use GetNext() method because GetAll() was called.");
 
                         return;

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/src/impl/interop/interop_input_stream.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/src/impl/interop/interop_input_stream.cpp b/modules/platform/src/main/cpp/core/src/impl/interop/interop_input_stream.cpp
index 2af4b72..c146482 100644
--- a/modules/platform/src/main/cpp/core/src/impl/interop/interop_input_stream.cpp
+++ b/modules/platform/src/main/cpp/core/src/impl/interop/interop_input_stream.cpp
@@ -176,7 +176,7 @@ namespace gridgain
             void InteropInputStream::Position(int32_t pos)
             {
                 if (pos > len) {
-                    GG_ERROR_FORMATTED_3(GridError::GG_ERR_MEMORY, "Requested input stream position is out of bounds",
+                    GG_ERROR_FORMATTED_3(GridError::IGNITE_ERR_MEMORY, "Requested input stream position is out of bounds",
                         "memPtr", mem->PointerLong(), "len", len, "pos", pos);
                 }
 
@@ -192,7 +192,7 @@ namespace gridgain
             void InteropInputStream::EnsureEnoughData(int32_t cnt)
             {
                 if (len - pos < cnt) {
-                    GG_ERROR_FORMATTED_4(GridError::GG_ERR_MEMORY, "Not enough data in the stream",
+                    GG_ERROR_FORMATTED_4(GridError::IGNITE_ERR_MEMORY, "Not enough data in the stream",
                         "memPtr", mem->PointerLong(), "len", len, "pos", pos, "requested", cnt);
                 }
             }

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/src/impl/interop/interop_memory.cpp
----------------------------------------------------------------------
diff --git a/modules/platform/src/main/cpp/core/src/impl/interop/interop_memory.cpp b/modules/platform/src/main/cpp/core/src/impl/interop/interop_memory.cpp
index 8a7903f..a8151f6 100644
--- a/modules/platform/src/main/cpp/core/src/impl/interop/interop_memory.cpp
+++ b/modules/platform/src/main/cpp/core/src/impl/interop/interop_memory.cpp
@@ -40,32 +40,32 @@ namespace gridgain
 
             int32_t InteropMemory::Capacity(int8_t* memPtr)
             {
-                return *reinterpret_cast<int32_t*>(memPtr + GG_MEM_HDR_OFF_CAP);
+                return *reinterpret_cast<int32_t*>(memPtr + IGNITE_MEM_HDR_OFF_CAP);
             }
 
             void InteropMemory::Capacity(int8_t* memPtr, int32_t val)
             {
-                *reinterpret_cast<int32_t*>(memPtr + GG_MEM_HDR_OFF_CAP) = val;
+                *reinterpret_cast<int32_t*>(memPtr + IGNITE_MEM_HDR_OFF_CAP) = val;
             }
 
             int32_t InteropMemory::Length(int8_t* memPtr)
             {
-                return *reinterpret_cast<int32_t*>(memPtr + GG_MEM_HDR_OFF_LEN);
+                return *reinterpret_cast<int32_t*>(memPtr + IGNITE_MEM_HDR_OFF_LEN);
             }
 
             void InteropMemory::Length(int8_t* memPtr, int32_t val)
             {
-                *reinterpret_cast<int32_t*>(memPtr + GG_MEM_HDR_OFF_LEN) = val;
+                *reinterpret_cast<int32_t*>(memPtr + IGNITE_MEM_HDR_OFF_LEN) = val;
             }
 
             int32_t InteropMemory::Flags(int8_t* memPtr)
             {
-                return *reinterpret_cast<int32_t*>(memPtr + GG_MEM_HDR_OFF_FLAGS);
+                return *reinterpret_cast<int32_t*>(memPtr + IGNITE_MEM_HDR_OFF_FLAGS);
             }
 
             void InteropMemory::Flags(int8_t* memPtr, int32_t val)
             {
-                *reinterpret_cast<int32_t*>(memPtr + GG_MEM_HDR_OFF_FLAGS) = val;
+                *reinterpret_cast<int32_t*>(memPtr + IGNITE_MEM_HDR_OFF_FLAGS) = val;
             }
 
             bool InteropMemory::IsExternal(int8_t* memPtr)
@@ -75,7 +75,7 @@ namespace gridgain
 
             bool InteropMemory::IsExternal(int32_t flags)
             {
-                return (flags & GG_MEM_FLAG_EXT) != GG_MEM_FLAG_EXT;
+                return (flags & IGNITE_MEM_FLAG_EXT) != IGNITE_MEM_FLAG_EXT;
             }
 
             bool InteropMemory::IsPooled(int8_t* memPtr)
@@ -85,7 +85,7 @@ namespace gridgain
 
             bool InteropMemory::IsPooled(int32_t flags)
             {
-                return (flags & GG_MEM_FLAG_POOLED) != 0;
+                return (flags & IGNITE_MEM_FLAG_POOLED) != 0;
             }
 
             bool InteropMemory::IsAcquired(int8_t* memPtr)
@@ -95,7 +95,7 @@ namespace gridgain
 
             bool InteropMemory::IsAcquired(int32_t flags)
             {
-                return (flags & GG_MEM_FLAG_ACQUIRED) != 0;
+                return (flags & IGNITE_MEM_FLAG_ACQUIRED) != 0;
             }
                 
             int8_t* InteropMemory::Pointer()
@@ -130,12 +130,12 @@ namespace gridgain
                 
             InteropUnpooledMemory::InteropUnpooledMemory(int32_t cap)
             {
-                memPtr = static_cast<int8_t*>(malloc(GG_MEM_HDR_LEN));
+                memPtr = static_cast<int8_t*>(malloc(IGNITE_MEM_HDR_LEN));
                 
                 Data(memPtr, malloc(cap));
                 Capacity(memPtr, cap);
                 Length(memPtr, 0);
-                Flags(memPtr, GG_MEM_FLAG_EXT);
+                Flags(memPtr, IGNITE_MEM_FLAG_EXT);
 
                 owning = true;
             }
@@ -173,7 +173,7 @@ namespace gridgain
             void InteropExternalMemory::Reallocate(int32_t cap)
             {
                 if (JniContext::Reallocate(reinterpret_cast<int64_t>(memPtr), cap) == -1) {
-                    GG_ERROR_FORMATTED_2(GridError::GG_ERR_MEMORY, "Failed to reallocate external memory", 
+                    GG_ERROR_FORMATTED_2(GridError::IGNITE_ERR_MEMORY, "Failed to reallocate external memory", 
                         "memPtr", PointerLong(), "requestedCapacity", cap)
                 }
             }
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/cache/cache.h b/modules/platform/src/main/cpp/core/include/gridgain/cache/cache.h
index be7ee61..81f01ab 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/cache/cache.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/cache/cache.h
@@ -62,7 +62,7 @@ namespace gridgain
 
             /**
              * Checks whether this cache contains no key-value mappings.
              * Semantically equals to Cache.Size(GG_PEEK_MODE_PRIMARY) == 0.
              *
              * @return True if cache is empty.
              */
@@ -79,7 +79,7 @@ namespace gridgain
 
             /**
              * Checks whether this cache contains no key-value mappings.
              * Semantically equals to Cache.Size(GG_PEEK_MODE_PRIMARY) == 0.
              *
              * @param err Error.
              * @return True if cache is empty.
@@ -953,7 +953,7 @@ namespace gridgain
              */
             int32_t LocalSize()
             {
-                return LocalSize(GG_PEEK_MODE_ALL);
+                return LocalSize(IGNITE_PEEK_MODE_ALL);
             }
 
             /**
@@ -964,7 +964,7 @@ namespace gridgain
              */
             int32_t LocalSize(GridError& err)
             {
-                return LocalSize(GG_PEEK_MODE_ALL, err);
+                return LocalSize(IGNITE_PEEK_MODE_ALL, err);
             }
 
             /**
@@ -1004,7 +1004,7 @@ namespace gridgain
              */
             int32_t Size()
             {
-                return Size(gridgain::cache::GG_PEEK_MODE_ALL);
+                return Size(gridgain::cache::IGNITE_PEEK_MODE_ALL);
             }
 
             /**
@@ -1016,7 +1016,7 @@ namespace gridgain
              */
             int32_t Size(GridError& err)
             {
-                return Size(gridgain::cache::GG_PEEK_MODE_ALL, err);
+                return Size(gridgain::cache::IGNITE_PEEK_MODE_ALL, err);
             }
 
             /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/cache/cache_peek_mode.h
----------------------------------------------------------------------
@@ -62,7 +62,7 @@ namespace gridgain
             /**
              * Checks whether this cache contains no key-value mappings.
-             * Semantically equals to Cache.Size(GG_PEEK_MODE_PRIMARY) == 0.
+             * Semantically equals to Cache.Size(IGNITE_PEEK_MODE_PRIMARY) == 0.
              *
              * @return True if cache is empty.
@@ -79,7 +79,7 @@ namespace gridgain
             /**
              * Checks whether this cache contains no key-value mappings.
-             * Semantically equals to Cache.Size(GG_PEEK_MODE_PRIMARY) == 0.
+             * Semantically equals to Cache.Size(IGNITE_PEEK_MODE_PRIMARY) == 0.
              *
              * @param err Error.
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/cache/cache_peek_mode.h b/modules/platform/src/main/cpp/core/include/gridgain/cache/cache_peek_mode.h
index b01f2d1..c00525d 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/cache/cache_peek_mode.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/cache/cache_peek_mode.h
@@ -30,40 +30,40 @@ namespace gridgain
             /**
              * Peeks into all available cache storages.
              */
-            GG_PEEK_MODE_ALL = 0x01,
+            IGNITE_PEEK_MODE_ALL = 0x01,
 
             /**
              * Peek into near cache only (don't peek into partitioned cache).
              * In case of LOCAL cache, behaves as GG_PEEK_MODE_ALL mode.
              */
-            GG_PEEK_MODE_NEAR = 0x02,
+            IGNITE_PEEK_MODE_NEAR = 0x02,
 
             /**
              * Peek value from primary copy of partitioned cache only (skip near cache).
              * In case of LOCAL cache, behaves as GG_PEEK_MODE_ALL mode.
              */
-            GG_PEEK_MODE_PRIMARY = 0x04,
+            IGNITE_PEEK_MODE_PRIMARY = 0x04,
 
             /**
              * Peek value from backup copies of partitioned cache only (skip near cache).
              * In case of LOCAL cache, behaves as GG_PEEK_MODE_ALL mode.
              */
-            GG_PEEK_MODE_BACKUP = 0x08,
+            IGNITE_PEEK_MODE_BACKUP = 0x08,
 
             /**
              * Peeks value from the on-heap storage only.
              */
-            GG_PEEK_MODE_ONHEAP = 0x10,
+            IGNITE_PEEK_MODE_ONHEAP = 0x10,
 
             /**
              * Peeks value from the off-heap storage only, without loading off-heap value into cache.
              */
-            GG_PEEK_MODE_OFFHEAP = 0x20,
+            IGNITE_PEEK_MODE_OFFHEAP = 0x20,
 
             /**
              * Peeks value from the swap storage only, without loading swapped value into cache.
              */
-            GG_PEEK_MODE_SWAP = 0x40
+            IGNITE_PEEK_MODE_SWAP = 0x40
         };
     }
 }

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/cache/query/query_cursor.h
----------------------------------------------------------------------
@@ -30,40 +30,40 @@ namespace gridgain
             /**
              * Peek into near cache only (don't peek into partitioned cache).
-             * In case of LOCAL cache, behaves as GG_PEEK_MODE_ALL mode.
+             * In case of LOCAL cache, behaves as IGNITE_PEEK_MODE_ALL mode.
              */
@@ -30,40 +30,40 @@ namespace gridgain
             /**
              * Peek value from primary copy of partitioned cache only (skip near cache).
-             * In case of LOCAL cache, behaves as GG_PEEK_MODE_ALL mode.
+             * In case of LOCAL cache, behaves as IGNITE_PEEK_MODE_ALL mode.
              */
@@ -30,40 +30,40 @@ namespace gridgain
             /**
              * Peek value from backup copies of partitioned cache only (skip near cache).
-             * In case of LOCAL cache, behaves as GG_PEEK_MODE_ALL mode.
+             * In case of LOCAL cache, behaves as IGNITE_PEEK_MODE_ALL mode.
              */
diff --git a/modules/platform/src/main/cpp/core/include/gridgain/grid_error.h b/modules/platform/src/main/cpp/core/include/gridgain/grid_error.h
index 54e1f53..b8d1099 100644
--- a/modules/platform/src/main/cpp/core/include/gridgain/grid_error.h
+++ b/modules/platform/src/main/cpp/core/include/gridgain/grid_error.h
@@ -74,115 +74,115 @@ namespace gridgain
     {
     public:
         /** Success. */
-        static const int GG_SUCCESS = 0;
+        static const int IGNITE_SUCCESS = 0;
 
         /** Failed to initialize JVM. */
-        static const int GG_ERR_JVM_INIT = 1;
+        static const int IGNITE_ERR_JVM_INIT = 1;
 
         /** Failed to attach to JVM. */
-        static const int GG_ERR_JVM_ATTACH = 2;
+        static const int IGNITE_ERR_JVM_ATTACH = 2;
         
         /** JVM library is not found. */
-        static const int GG_ERR_JVM_LIB_NOT_FOUND = 3;
+        static const int IGNITE_ERR_JVM_LIB_NOT_FOUND = 3;
 
         /** Failed to load JVM library. */
-        static const int GG_ERR_JVM_LIB_LOAD_FAILED = 4;
+        static const int IGNITE_ERR_JVM_LIB_LOAD_FAILED = 4;
         
         /** JVM classpath is not provided. */
-        static const int GG_ERR_JVM_NO_CLASSPATH = 5;
+        static const int IGNITE_ERR_JVM_NO_CLASSPATH = 5;
 
         /** JVM error: no class definition found. */
-        static const int GG_ERR_JVM_NO_CLASS_DEF_FOUND = 6;
+        static const int IGNITE_ERR_JVM_NO_CLASS_DEF_FOUND = 6;
 
         /** JVM error: no such method. */
-        static const int GG_ERR_JVM_NO_SUCH_METHOD = 7;
+        static const int IGNITE_ERR_JVM_NO_SUCH_METHOD = 7;
 
         /** Memory operation error. */
-        static const int GG_ERR_MEMORY = 1001;
+        static const int IGNITE_ERR_MEMORY = 1001;
 
         /** Portable error. */
-        static const int GG_ERR_PORTABLE = 1002;
+        static const int IGNITE_ERR_PORTABLE = 1002;
 
         /** Generic GridGain error. */
-        static const int GG_ERR_GENERIC = 2000;
+        static const int IGNITE_ERR_GENERIC = 2000;
 
         /** Illegal argument passed. */
-        static const int GG_ERR_ILLEGAL_ARGUMENT = 2001;
+        static const int IGNITE_ERR_ILLEGAL_ARGUMENT = 2001;
 
         /** Illegal state. */
-        static const int GG_ERR_ILLEGAL_STATE = 2002;
+        static const int IGNITE_ERR_ILLEGAL_STATE = 2002;
 
         /** Unsupported operation. */
-        static const int GG_ERR_UNSUPPORTED_OPERATION = 2003;
+        static const int IGNITE_ERR_UNSUPPORTED_OPERATION = 2003;
 
         /** Thread has been interrup. */
-        static const int GG_ERR_INTERRUPTED = 2004;
+        static const int IGNITE_ERR_INTERRUPTED = 2004;
 
         /** Cluster group is empty. */
-        static const int GG_ERR_CLUSTER_GROUP_EMPTY = 2005;
+        static const int IGNITE_ERR_CLUSTER_GROUP_EMPTY = 2005;
 
         /** Cluster topology problem. */
-        static const int GG_ERR_CLUSTER_TOPOLOGY = 2006;
+        static const int IGNITE_ERR_CLUSTER_TOPOLOGY = 2006;
 
         /** Compute execution rejected. */
-        static const int GG_ERR_COMPUTE_EXECUTION_REJECTED = 2007;
+        static const int IGNITE_ERR_COMPUTE_EXECUTION_REJECTED = 2007;
 
         /** Compute job failover. */
-        static const int GG_ERR_COMPUTE_JOB_FAILOVER = 2008;
+        static const int IGNITE_ERR_COMPUTE_JOB_FAILOVER = 2008;
 
         /** Compute task cancelled. */
-        static const int GG_ERR_COMPUTE_TASK_CANCELLED = 2009;
+        static const int IGNITE_ERR_COMPUTE_TASK_CANCELLED = 2009;
 
         /** Compute task timeout. */
-        static const int GG_ERR_COMPUTE_TASK_TIMEOUT = 2010;
+        static const int IGNITE_ERR_COMPUTE_TASK_TIMEOUT = 2010;
 
         /** Compute user undeclared exception. */
-        static const int GG_ERR_COMPUTE_USER_UNDECLARED_EXCEPTION = 2011;
+        static const int IGNITE_ERR_COMPUTE_USER_UNDECLARED_EXCEPTION = 2011;
 
         /** Generic cache error. */
-        static const int GG_ERR_CACHE = 2012;
+        static const int IGNITE_ERR_CACHE = 2012;
 
         /** Generic cache loader error. */
-        static const int GG_ERR_CACHE_LOADER = 2013;
+        static const int IGNITE_ERR_CACHE_LOADER = 2013;
 
         /** Generic cache writer error. */
-        static const int GG_ERR_CACHE_WRITER = 2014;
+        static const int IGNITE_ERR_CACHE_WRITER = 2014;
         
         /** Generic cache entry processor error. */
-        static const int GG_ERR_ENTRY_PROCESSOR = 2015;
+        static const int IGNITE_ERR_ENTRY_PROCESSOR = 2015;
 
         /** Cache atomic update timeout. */
-        static const int GG_ERR_CACHE_ATOMIC_UPDATE_TIMEOUT = 2016;
+        static const int IGNITE_ERR_CACHE_ATOMIC_UPDATE_TIMEOUT = 2016;
 
         /** Cache partial update. */
-        static const int GG_ERR_CACHE_PARTIAL_UPDATE = 2017;
+        static const int IGNITE_ERR_CACHE_PARTIAL_UPDATE = 2017;
         
         /** Transaction optimisitc exception. */
-        static const int GG_ERR_TX_OPTIMISTIC = 2018;
+        static const int IGNITE_ERR_TX_OPTIMISTIC = 2018;
 
         /** Transaction timeout. */
-        static const int GG_ERR_TX_TIMEOUT = 2019;
+        static const int IGNITE_ERR_TX_TIMEOUT = 2019;
 
         /** Transaction rollback. */
-        static const int GG_ERR_TX_ROLLBACK = 2020;
+        static const int IGNITE_ERR_TX_ROLLBACK = 2020;
 
         /** Transaction heuristic exception. */
-        static const int GG_ERR_TX_HEURISTIC = 2021;
+        static const int IGNITE_ERR_TX_HEURISTIC = 2021;
 
         /** Authentication error. */
-        static const int GG_ERR_AUTHENTICATION = 2022;
+        static const int IGNITE_ERR_AUTHENTICATION = 2022;
 
         /** Security error. */
-        static const int GG_ERR_SECURITY = 2023;
+        static const int IGNITE_ERR_SECURITY = 2023;
         
         /** Product license error. */
-        static const int GG_ERR_PRODUCT_LICENSE = 2024;
+        static const int IGNITE_ERR_PRODUCT_LICENSE = 2024;
 
         /** Unknown error. */
-        static const int GG_ERR_UNKNOWN = -1;
+        static const int IGNITE_ERR_UNKNOWN = -1;
 
         /**
          * Throw an error if code is not GG_SUCCESS.
          *
          * @param err Error.
          */

http://git-wip-us.apache.org/repos/asf/ignite/blob/7c4165ee/modules/platform/src/main/cpp/core/include/gridgain/impl/interop/interop_memory.h
----------------------------------------------------------------------
@@ -74,115 +74,115 @@ namespace gridgain
 
         /**
-         * Throw an error if code is not GG_SUCCESS.
+         * Throw an error if code is not IGNITE_SUCCESS.
          *
          * @param err Error.